@@ -3,9 +3,12 @@
 roxygen()
 
 
-
+setOldClass("mesh3d")
 setOldClass(c("file", "connection"))
 setOldClass(c("gzfile", "connection"))
+setOldClass("raster")
+setOldClass("rastergrob")
+setOldClass("gList")
 
 .package_env <- new.env()
 
@@ -117,6 +120,22 @@ setClass("NIfTIFileDescriptor", contains=c("BrainFileDescriptor"))
 #' @export
 setClass("AFNIFileDescriptor", contains=c("BrainFileDescriptor"))
 
+
+#' NIMLSurfaceFileDescriptor
+#' 
+#' This class supports the NIML file format for surface-based data
+#' @rdname NIMLSurfaceFileDescriptor-class
+#' @export
+setClass("NIMLSurfaceFileDescriptor", contains=c("BrainFileDescriptor"))
+
+#' FresurferAsciiSurfaceFileDescriptor
+#' 
+#' This class supports the FreesurferAsciiSurfaceFileDescriptor file format for surface geometry
+#' @rdname FreesurferAsciiSurfaceFileDescriptor-class
+#' @export
+setClass("FreesurferAsciiSurfaceFileDescriptor", contains=c("BrainFileDescriptor"))
+
+
 #' BaseMetaInfo
 #' 
 #' This is a base class to represent meta information
@@ -150,6 +169,78 @@ setMethod(f="show",
 				cat("meta info is null \n")
 			})
 	
+
+#' SurfaceGeometryMetaInfo
+#' 	
+#' This class contains meta information for brain surface geometry
+#' 
+#' @rdname SurfaceGeometryMetaInfo-class
+#' @slot headerFile name of the file containing meta information
+#' @slot dataFile name of the file containing data
+#' @slot fileDescriptor descriptor of image file format
+#' @slot vertices the number of surface vertices
+#' @slot faces the number of faces
+#' @slot embedDimension the dimensionality of the embedding
+#' @slot label a label indicating the type of surface (e.g. white, pial, inflated, flat, spherical)
+#' @export	 							 
+setClass("SurfaceGeometryMetaInfo",
+         representation=
+           representation(
+             headerFile="character",
+             dataFile="character",
+             fileDescriptor="BrainFileDescriptor",
+             vertices="integer",
+             faces="integer",
+             label="character",
+             embedDimension="integer"),
+         contains=c("BaseMetaInfo"))
+
+#' FreeSurferSurfaceGeometryMetaInfo
+#' 	
+#' This class contains meta information for brain surface geometry
+#' 
+#' @rdname FreeSurferSurfaceGeometryMetaInfo-class
+#' @export	 							 
+setClass("FreesurferSurfaceGeometryMetaInfo", contains=c("SurfaceGeometryMetaInfo"))
+
+#' SurfaceDataMetaInfo
+#' 	
+#' This class contains meta information for surface-based data (the values that map to a surface geometry)
+#' 
+#' @rdname SurfaceDataMetaInfo-class
+#' @slot headerFile name of the file containing meta information
+#' @slot dataFile name of the file containing data
+#' @slot fileDescriptor descriptor of image file format
+#' @slot nodeCount the number of nodes for which surface data exists
+#' @slot nels the number of data vectors (typically the number of columns in the surface data matrix; nels = 1 for a single surface data set)
+#' @slot label a label indicating the type of surface (e.g. white, pial, inflated, flat, spherical)
+#' @export	 							 
+setClass("SurfaceDataMetaInfo",
+         representation=
+           representation(
+             headerFile="character",
+             dataFile="character",
+             fileDescriptor="BrainFileDescriptor",
+             nodeCount="integer",
+             nels="integer",
+             label="character"),
+         contains=c("BaseMetaInfo"))
+
+#' NIMLSurfaceDataMetaInfo
+#' 	
+#' This class contains meta information for surface-based data for the NIML data format
+#' 
+#' @rdname NIMLSurfaceDataMetaInfo-class
+#' @slot data the numeric data matrix of surface values (rows = nodes, columns=surface vectors)
+#' @slot nodeIndices the indices of the nodes for mapping to associated surface geometry.
+#' @export	 							 
+setClass("NIMLSurfaceDataMetaInfo",
+         representation=
+           representation(
+             data="matrix",
+             nodeIndices="integer"),
+         contains=c("SurfaceDataMetaInfo"))
+
 #' BrainMetaInfo
 #' 	
 #' This class contains meta information from an image
@@ -220,6 +311,7 @@ setClass("NIfTIMetaInfo",
 #' 
 #' This class contains meta information for a AFNI image file
 #' @rdname FileMetaInfo-class  
+#' @slot afni_header a list of attributes specific to the AFNI file format 
 #' @slot afni_header a \code{list} of attributes specific to the AFNI file format 
 #' @export
 setClass("AFNIMetaInfo",
@@ -270,6 +362,7 @@ setClass("BrainFileSource", representation=
 				contains=c("BrainSource"))
 
 		
+#' BrainVolume
 #' BrainVolumeSource
 #' 		
 #' A class is used to produce a \code{\linkS4class{BrainVolume}} instance
@@ -282,13 +375,26 @@ setClass("BrainFileSource", representation=
 
 #' BrainVectorSource
 #' 
-#' A class that is used to produce a \code{\linkS4class{BrainVector}} instance
+#' A class that is used to produce a \code{\linkS4class{BrainVectorSource}} instance
 #' @rdname BrainVectorSource-class
 #' @slot indices the index vector of the volumes to be loaded
 #' @export
 		setClass("BrainVectorSource", representation=
 						representation(indices="integer"),
 				contains=c("BrainSource"))
+
+
+#' BrainSurfaceVectorSource
+#' 
+#' A class that is used to produce a \code{\linkS4class{BrainSurfaceVectorSource}} instance
+#' 
+#' @rdname BrainSurfaceVectorSource-class
+#' @slot indices the index vector of the volumes to be loaded
+#' @export
+setClass("BrainSurfaceVectorSource", representation=
+           representation(indices="integer"),
+         contains=c("BaseSource"))
+
 		
 		
 #' BrainBucketSource
@@ -302,7 +408,18 @@ setClass("BrainFileSource", representation=
 				representation=representation(sourceList="list", cache="environment"),
 				contains=c("BrainVectorSource"))
 		
-		
+#' BrainSurfaceSource
+#' 
+#' A class that is used to produce a \code{\linkS4class{BrainSurface}} instance
+#' @rdname BrainSurfaceSource-class
+#' @slot metaInfo a \code{\linkS4class{SurfaceGeometryMetaInfo}} instance
+#' @slot dataMetaInfo a \code{\linkS4class{SurfaceDataMetaInfo}} instance
+#' @slot index the index offset into the surface data matrix
+#' @export
+setClass("BrainSurfaceSource",
+         representation=representation(metaInfo="SurfaceGeometryMetaInfo", dataMetaInfo="SurfaceDataMetaInfo", index="integer"),
+         contains=c("BaseSource"))
+
 
 #' BinaryReader
 #' 
@@ -321,6 +438,19 @@ setClass("BinaryReader", representation=
 							   bytesPerElement="integer",
 							   endian="character"))
 
+
+#' ColumnReader
+#' 
+#' This class supports reading of data froma matrix-like stroage format
+#' @rdname ColumnReader-class
+#' @slot nrow the number of rows
+#' @slot ncol the number of columns
+#' @slot reader a function that takes a set of column indices and returns a \code{matrix}
+#' @export
+setClass("ColumnReader", representation=
+           representation(nrow="integer", ncol="integer", reader="function"))
+
+         
 #' BinaryWriter
 #' 
 #' This class supports writing of bulk binary data to a connection
@@ -371,6 +501,8 @@ setClass("BrainSpace",
       }
     })
          
+
+
 #' BrainData
 #' 
 #' Base class for brain image data
@@ -539,6 +671,28 @@ setClass("Kernel",
 
 ## TODO add a LazyBrainBucket class
 
+#' BrainSurface
+#' 
+#' a three-dimensional surface consisting of a set of triangle vertices with one value per vertex.
+#' @rdname BrainSurface-class
+#' @slot source the data source for the surface
+#' @slot mesh the underlying \code{mesh3d} object 
+#' @slot data the vector of data value at each vertex of the mesh
+#' @export
+setClass("BrainSurface", 
+         representation=representation(source="BrainSource", mesh="mesh3d", data="numeric"))
+
+#' BrainSurfaceVector
+#' 
+#' a three-dimensional surface consisting of a set of triangle vertices with multiple values per vertex.
+#' 
+#' @rdname BrainSurfaceVector-class
+#' @slot source the data source for the surface
+#' @slot mesh the underlying \code{mesh3d} object 
+#' @slot mat a matrix of values where each column contains a vector of values over the surface nodes.
+#' @export
+setClass("BrainSurfaceVector", 
+         representation=representation(source="BrainSource", mesh="mesh3d", mat="numeric"))
 
 #' BrainBucket
 #' 
@@ -573,11 +727,23 @@ setClass("BrainBucket",
 #' @slot thresh cut-off value above which vlaues will be made transparent.
 #' @slot axis the axis index of perpendicular to the xy plane (option: 1,2,3; default is 3)
 #' @slot zero.col the color pixels with intensity of zero. This value overrides the color from the slot \code{colorMap}
+#' @slot alpha the transparency of the layer
 #' @export
 setClass("Layer",
-         representation=representation(vol="BrainVolume", colorMap="vector", thresh="numeric", axis="numeric", zero.col="character"))
+         representation=representation(vol="BrainVolume", colorMap="vector", thresh="numeric", axis="numeric", zero.col="character", alpha="numeric"))
 
 setClass("Overlay",
                   representation(layers="list"))
                   
 
+setClass("RenderedSlice",
+         representation=representation(slice="BrainSlice",
+                                       width="numeric",
+                                       height="numeric",
+                                       raster="rastergrob"))
+
+setClass("RenderedSliceStack",
+         representation=representation(slices="list",
+                                       width="numeric",
+                                       height="numeric",
+                                       grob="gList"))
